Utilities Reference — Geraldo Reports Documentation v0.3.6-stable documentation

### Navigation

- index
- next |
- previous |
- Geraldo Reports Documentation v0.3.6-stable documentation »

# Utilities Reference

## landscape

`geraldo.utils.` `landscape`()

Path: geraldo.landscape

Page sizes are tuples with 2 nodes: first with width and second width height.

landscape is a helper function to invert this tuple.

## BAND_WIDTH

`geraldo.utils.` `BAND_WIDTH`

Path: geraldo.BAND_WIDTH

Once you use this constant in a widget or graphic width, it will assume its band width automatically.

### Navigation

- index
- next |
- previous |
- Geraldo Reports Documentation v0.3.6-stable documentation »